==> torque-5.1-source-release.zip: torque-5.1/torque-generator/src/main/java/org/apache/torque/generator/source/SourcePathPointer.java <==
package org.apache.torque.generator.source;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * A class containing the value and the path to an object in a model graph
 */
public class SourcePathPointer
{
    /** The value of the object. */
    private final Object value;

    /** The path to the object. */
    private final String path;

    public SourcePathPointer(final Object value, final String path)
    {
        this.value = value;
        this.path = path;
    }

    public Object getValue()
    {
        return value;
    }

    public String getPath()
    {
        return path;
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((path == null) ? 0 : path.hashCode());
        result = prime * result + ((value == null) ? 0 : value.hashCode());
        return result;
    }

    @Override
    public boolean equals(final Object obj)
    {
        if (this == obj)
        {
            return true;
        }
        if (obj == null)
        {
            return false;
        }
        if (getClass() != obj.getClass())
        {
            return false;
        }
        SourcePathPointer other = (SourcePathPointer) obj;
        if (path == null)
        {
            if (other.path != null)
            {
                return false;
            }
        }
        else if (!path.equals(other.path))
        {
            return false;
        }
        if (value == null)
        {
            if (other.value != null)
            {
                return false;
            }
        }
        else if (!value.equals(other.value))
        {
            return false;
        }
        return true;
    }

    @Override
    public String toString()
    {
        return "SourcePathPointer [value=" + value + ", path=" + path + "]";
    }
}

==> torque-6.0-source-release.zip: torque-6.0/torque-generator/src/main/java/org/apache/torque/generator/source/SourcePathPointer.java <==
package org.apache.torque.generator.source;

import java.util.Objects;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * A class containing the value and the path to an object in a model graph
 */
public class SourcePathPointer
{
    /** The value of the object. */
    private final Object value;

    /** The path to the object. */
    private final String path;

    public SourcePathPointer(final Object value, final String path)
    {
        this.value = value;
        this.path = path;
    }

    public Object getValue()
    {
        return value;
    }

    public String getPath()
    {
        return path;
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(path, value);
    }

    @Override
    public boolean equals(final Object obj)
    {
        if (this == obj)
        {
            return true;
        }
        if ((obj == null) || (getClass() != obj.getClass()))
        {
            return false;
        }
        SourcePathPointer other = (SourcePathPointer) obj;
        if (!Objects.equals(path, other.path))
        {
            return false;
        }
        if (!Objects.equals(value, other.value))
        {
            return false;
        }
        return true;
    }

    @Override
    public String toString()
    {
        return "SourcePathPointer [value=" + value + ", path=" + path + "]";
    }
}
